@@ -7,6 +7,9 @@ use base 'Test::Run::Base::PlugHelpers';
 
 use vars qw($VERSION);
 
+use MRO::Compat;
+
+
 use List::MoreUtils ();
 
 use Fatal qw(opendir);
@@ -26,11 +29,11 @@ Test::Run::Core - Base class to run standard TAP scripts.
 
 =head1 VERSION
 
-Version 0.0117
+Version 0.0118
 
 =cut
 
-$VERSION = '0.0117';
+$VERSION = '0.0118';
 
 $ENV{HARNESS_ACTIVE} = 1;
 $ENV{HARNESS_NG_VERSION} = $VERSION;
@@ -120,7 +123,7 @@ sub _init
 {
     my ($self, $args) = @_;
 
-    $self->NEXT::_init($args);
+    $self->maybe::next::method($args);
 
     $self->Columns(80);
     $self->Switches("-w");
